@@ -7,7 +7,7 @@
 #' links, areas with clusters, variables, etc.). 
 #' 
 #' @details 
-#' The simulation choosen with \code{setSimulationPath} becomes the default
+#' The simulation chosen with \code{setSimulationPath} becomes the default
 #' simulation for all functions of the package. This behavior is fine when
 #' working on only one simulation, but it may become problematic when working
 #' on multiple simulations at same time.
@@ -28,7 +28,7 @@
 #'   select the most recent simulation, -2 will the penultimate one, etc. There 
 #'   are two special values 0 and "input" that tells the function that the user
 #'   is not interested by the results of any simulation, but only by the inputs.
-#'   In such a case, the function \code{\link{readAntares}} is anavailable. 
+#'   In such a case, the function \code{\link{readAntares}} is unavailable. 
 #'
 #' @return A list containing various information about the simulation, in particular:
 #'   \item{studyPath}{path of the Antares study}
@@ -309,7 +309,7 @@ setSimulationPath <- function(path, simulation = NULL) {
     
     if (length(to) == 0) return(NULL)
     
-    data.frame(link = paste(f, "-", to), from = f, to = to)
+    data.frame(link = paste(f, "-", to), from = f, to = to, stringsAsFactors = TRUE)
   })
   linksDef <- data.table(linksDef)
   
@@ -493,7 +493,7 @@ setSimulationPath <- function(path, simulation = NULL) {
     }
     if (length(areas) == 0) return(NULL)
     
-    data.frame(district = tolower(n), area = tolower(areas))
+    data.frame(district = tolower(n), area = tolower(areas), stringsAsFactors = TRUE)
   })
   data.table(res)
 }
